@@ -2,7 +2,7 @@ package Datahub::Factory::Command::transport;
 
 use Datahub::Factory::Sane;
 
-our $VERSION = '1.71';
+our $VERSION = '1.72';
 
 use parent 'Datahub::Factory::Cmd';
 
@@ -58,7 +58,7 @@ sub execute {
     #    nice errors.
     $self->info("Loading pipeline configuration...");
     my ($pipeline, $options);
-    $pipeline = Datahub::Factory->pipeline($opt->{pipeline});
+    $pipeline = Datahub::Factory->pipeline($opt->{pipeline}, 'Transport');
     $options = $pipeline->parse();
 
     # Load modules
